//-*-c++-*-
#ifndef TULIP_METAGRAPHPROXY_H
#define TULIP_METAGRAPHPROXY_H

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "PropertyProxy.h"
#include "MethodFactory.h"
#include "TemplateFactory.h"

class PropertyContext;

/** \addtogroup properties */ 
/*@{*/
class TLP_SCOPE MetaGraphProxy:public PropertyProxy<MetaGraphType,MetaGraphType> { 
  friend class MetaGraph;

public :
  MetaGraphProxy (SuperGraph *);
  ~MetaGraphProxy();
  PProxy* clonePrototype(SuperGraph *, std::string );
  void copy( const node, const node, PProxy * );
  void copy( const edge, const edge, PProxy * );
};
/*@}*/
#endif

